#pragma once
#include <string>
#include <string.h>
using namespace std;

#include "../../Tool_Common/RsDataType.h"

// Flash ID code type
typedef enum
{
    _ENUM_FLASH_IDCODE_TYPE_START = 0,
    _ENUM_FLASH_IDCODE_TYPE_9FAB = _ENUM_FLASH_IDCODE_TYPE_START,
	_ENUM_FLASH_IDCODE_TYPE_9F90,
    _ENUM_FLASH_IDCODE_TYPE_END,
}ENUM_FLASH_IDCODE_TYPE;

// When flash conflict, select a priority one from one of them
typedef enum
{
    _ENUM_FLASH_EQUAL = 0,
    _ENUM_FLASH_PRIORITY,
    _ENUM_FLASH_UNIQUE,
}ENUM_FLASH_PRIORITY;

#define UL_IDCODE_LEN 8
#define UL_SR_OPCODE_LEN 5
#define UL_SR_MAX_COUNT 4
#define MAX_DIR_LENGTH 256


class CCpFlash
{
public:
	CCpFlash();
	~CCpFlash();

	void SetIDType(const ENUM_FLASH_IDCODE_TYPE &enumIDType) {m_enumIDType = enumIDType;};
	ENUM_FLASH_IDCODE_TYPE GetIDType() const {return m_enumIDType;};

	void SetIDCode(BYTE *pucIDCode){memcpy(m_ucszIDCode, pucIDCode, UL_IDCODE_LEN);};
	void GetIDCode(BYTE *pucIDCode){memcpy(pucIDCode, m_ucszIDCode, UL_IDCODE_LEN);};

	void SetFlashName(const string &strFlashName) {m_strFlashName = strFlashName;};
	string GetFlashName() const {return m_strFlashName;};

	void SetBankCount(const WORD usBankCount) {m_usBankCount = usBankCount;};
	WORD GetBankCount() const {return m_usBankCount;};

	void SetSRByteCount(const BYTE &ucSRByteCount) {m_ucSRByteCount = ucSRByteCount;};
	BYTE GetSRByteCount() const {return m_ucSRByteCount;};

	void SetFlashPriority(const ENUM_FLASH_PRIORITY &enumPriority) {m_enumPriority = enumPriority;};
	ENUM_FLASH_PRIORITY GetFlashPriority() {return m_enumPriority;};

	void SetSROPCode(BYTE *pucSROPCode){memcpy(m_ucszSROPCode, pucSROPCode, UL_SR_OPCODE_LEN);};
	void GetSROPCode(BYTE *pucSROPCode){memcpy(pucSROPCode, m_ucszSROPCode, UL_SR_OPCODE_LEN);};

	void SetEWPSR(BYTE *pucEWPSR){memcpy(m_ucszEWPSR, pucEWPSR, UL_SR_MAX_COUNT);};
	void GetEWPSR(BYTE *pucEWPSR){memcpy(pucEWPSR, m_ucszEWPSR, UL_SR_MAX_COUNT);};

	void SetDWPSR(BYTE *pucDWPSR){memcpy(m_ucszDWPSR, pucDWPSR, UL_SR_MAX_COUNT);};
	void GetDWPSR(BYTE *pucDWPSR){memcpy(pucDWPSR, m_ucszDWPSR, UL_SR_MAX_COUNT);};

	void SetEnableSWREN(const BOOL &bEnableSWREN) {m_bEnableSWREN = bEnableSWREN;};
	BOOL GetEnableSWREN() const {return m_bEnableSWREN;};

	void SetSendSWRENEveryPage(const BOOL &bSendSWRENEveryPage) {m_bSendSWRENEveryPage = bSendSWRENEveryPage;};
	BOOL GetSendSWRENEveryPage() const {return m_bSendSWRENEveryPage;};

	void SetSWRENCmd(const string &strSWRENCmd) {m_strSWRENCmd = strSWRENCmd;};
	string GetSWRENCmd() const {return m_strSWRENCmd;};

	void SetEnableSafeGuard(const BOOL &bEnableSafeGuard) {m_bEnableSafeGuard = bEnableSafeGuard;};
	BOOL GetEnableSafeGuard() const {return m_bEnableSafeGuard;};

	void SetSendSafeGuardCmdEveryPage(const BOOL &bSendSafeGuardCmdEveryPage) {m_bSendSafeGuardCmdEveryPage = bSendSafeGuardCmdEveryPage;};
	BOOL GetSendSafeGuardCmdEveryPage() const {return m_bSendSafeGuardCmdEveryPage;};

	void SetDisableSafeGuardCmd(const string &strDisableSafeGuardCmd) {m_strDisableSafeGuardCmd = strDisableSafeGuardCmd;};
	string GetDisableSafeGuardCmd() const {return m_strDisableSafeGuardCmd;};

	void SetEnableSafeGuardCmd(const string &strEnableSafeGuardCmd) {m_strEnableSafeGuardCmd = strEnableSafeGuardCmd;};
	string GetEnableSafeGuardCmd() const {return m_strEnableSafeGuardCmd;};

	void SetWriteFlashSRCmd(const BYTE &ucWriteFlashSRCmd) {m_ucWriteFlashSRCmd = ucWriteFlashSRCmd;};
	BYTE GetWriteFlashSRCmd() const {return m_ucWriteFlashSRCmd;};

private:
	ENUM_FLASH_IDCODE_TYPE m_enumIDType;
	BYTE m_ucszIDCode[UL_IDCODE_LEN];
	string m_strFlashName;
	WORD m_usBankCount;
	BYTE m_ucSRByteCount;
	// Use ENUM_FLASH_PRIORITY
	ENUM_FLASH_PRIORITY m_enumPriority;

	//m_ucszSROPCode[0] ReadHighSROP
	//m_ucszSROPCode[1] ReadThirdSROP  m_ucszSROPCode[2] WriteThirdSROP
	//m_ucszSROPCode[3] ReadFourthSROP m_ucszSROPCode[4] WriteFourthSROP
	BYTE m_ucszSROPCode[UL_SR_OPCODE_LEN];

	BYTE m_ucszEWPSR[UL_SR_MAX_COUNT];
	BYTE m_ucszDWPSR[UL_SR_MAX_COUNT];

	//SWREN
	BOOL m_bEnableSWREN;
	BOOL m_bSendSWRENEveryPage;
	string m_strSWRENCmd;

	// SafeGuard ر
	BOOL m_bEnableSafeGuard;
	BOOL m_bSendSafeGuardCmdEveryPage;
	string m_strEnableSafeGuardCmd;
	string m_strDisableSafeGuardCmd;

	// Write Flash SR Cmd
	BYTE m_ucWriteFlashSRCmd;
};
