#include "LinuxDevI2CRw.h"
#include <stdio.h>
#include <linux/i2c-dev.h>
#include <fcntl.h>
#include <errno.h>
#include <unistd.h>
#include <stdlib.h>
#include <stdbool.h>
#include <string.h>
#include <sys/ioctl.h>
using namespace std;

CDevI2CRw::CDevI2CRw(void)
{
    m_ucSlaveAddr = 0xFF;
    m_fd = -1;
}

CDevI2CRw::~CDevI2CRw(void)
{

}

STRUCT_ENUM_ERROR_TYPE CDevI2CRw::InitI2CDev()
{
    char filename[20];
    int devNum = 0;
    WORD usAddrIndex = 0;
    BYTE ucValue;
    
    for(devNum = 0; devNum < 256; devNum++)
    {
        sprintf(filename, "/dev/i2c-%d", devNum);
        m_fd = open(filename, O_RDWR);
        if(m_fd < 0)
        {
            //printf("open %s fail\n", filename);
            continue;
        }

        for(usAddrIndex = 0; usAddrIndex < US_SCALER_SLAVE_ADDR_AUTO_DEV; usAddrIndex++)
        {
            if(_ERROR_SUCCESS == IICCurrentRead(ST_SLAVE_AUTO_DEV[usAddrIndex].ucIspSlave, 1, &ucValue))
            {
                return _ERROR_SUCCESS;
            }
        }

        close(m_fd);

    }
    if(devNum == 256)
    {
        printf("Error: no i2c device connected to RT IC\n");
    }
    return _ERROR_COMM_SMBUS_INIT_FAIL;
}

STRUCT_ENUM_ERROR_TYPE CDevI2CRw::ReleaseI2CDev()
{
    if(m_fd != -1)
    {
        close(m_fd);
        m_fd = -1;
    }
    return _ERROR_SUCCESS;
}

STRUCT_ENUM_ERROR_TYPE CDevI2CRw::IICWrite(BYTE ucSlave, BYTE ucSub, WORD usLength, const BYTE* pucBuf)
{
    int status = 0;
    BYTE ucBuf[257] = {0};

    if(ucSlave != m_ucSlaveAddr)
    {
        status = ioctl(m_fd, I2C_SLAVE, (ucSlave >> 1));
        if(status < 0)
        {
            //printf("ERROR:Set slave adress 0x%x error\n", ucSlave);
            return _ERROR_LINUX_I2C_SET_SLAVE_ADDRESS;
        } 
        m_ucSlaveAddr = ucSlave;    
    }
    ucBuf[0] = ucSub;
    memcpy(ucBuf + 1, pucBuf, usLength);
    status = write(m_fd, ucBuf, usLength + 1);
    if((status < 0) || (status != (usLength + 1)))
    {
        //printf("ERROR:Write Data Error len 0x%x staus :0x%x\n", usLength, status);
        return _ERROR_LINUX_I2C_WRITE_FAIL;
    } 
    return _ERROR_SUCCESS;
}

STRUCT_ENUM_ERROR_TYPE CDevI2CRw::IICRead(BYTE ucSlave, BYTE ucSub, WORD usLength, BYTE* pucBuf)
{
    int status = 0;
    BYTE ucBuf[257] = {0};
    if(ucSlave != m_ucSlaveAddr)
    {
        status = ioctl(m_fd, I2C_SLAVE, (ucSlave >> 1));
        if(status < 0)
        {
            //printf("ERROR:Set slave adres error0x%x\n", ucSlave);
            return _ERROR_LINUX_I2C_SET_SLAVE_ADDRESS;
        } 
        m_ucSlaveAddr = ucSlave;
        
    }
    ucBuf[0] = ucSub;
    status = write(m_fd, ucBuf, 1);
    if((status < 0) || (status != 1))
    {
        //printf("ERROR:Write sub :0x%x status :0x%x\n", ucSub, status);
        return _ERROR_LINUX_I2C_WRITE_FAIL;
    } 

    status = read(m_fd, pucBuf, usLength);
    if((status < 0) || (status != usLength))
    {
        //printf("ERROR:READ Data FAil\n");
        return _ERROR_LINUX_I2C_READ_FAIL;
    } 
    
    return _ERROR_SUCCESS;
}

STRUCT_ENUM_ERROR_TYPE CDevI2CRw::IICCurrentRead(BYTE ucSlave, WORD usLength, BYTE* pucBuf)
{
    int status = 0;
    if(ucSlave != m_ucSlaveAddr)
    {
        status = ioctl(m_fd, I2C_SLAVE, (ucSlave >> 1));
        if(status < 0)
        {
            //printf("ERROR:Set slave adres error\n");
            return _ERROR_LINUX_I2C_SET_SLAVE_ADDRESS;
        } 
        m_ucSlaveAddr = ucSlave;
        
    }

    status = read(m_fd, pucBuf, usLength);
    if((status < 0) || (status != usLength))
    {
        //printf("ERROR:READ Data FAil\n");
        return _ERROR_LINUX_I2C_READ_FAIL;
    } 
    
    return _ERROR_SUCCESS;
}
